@@ -6,8 +6,7 @@ from langtrace_python_sdk.utils.with_root_span import with_langtrace_root_span
 
 _ = load_dotenv(find_dotenv())
 
-langtrace.init(batch=False, log_spans_to_console=True,
-               write_to_remote_url=False)
+langtrace.init(batch=False, log_spans_to_console=True, write_to_remote_url=False)
 
 client = OpenAI()
 
